year

# XMLRésuméLibrary: User Guide

ward | Element Reference | zip

## Name

year — A year

## Synopsis

### Content Model

    (#PCDATA)

### Attributes

Name | Type | Default
--- | --- | ---
targets | CDATA | None

## Description

The `year` element contains a year number, along with a possible string that identifies the date system, such as “B.C.” or “A.D.”.

### Parents

`year` may be contained in these elements: `copyright`, `date`, `pubDate`

## Examples

    <year>1995</year>

    <year>240 A.D.</year>

ward | Element Reference | zip